@@ -14,9 +14,8 @@ def clean_keywords(keywords):
 
 def make_keywords(dataset):
   kw_model = KeyBERT()
-  df = pd.DataFrame()
-  df["text"] = dataset["text"] or dataset["target"] or dataset["article"]
-  df["keywords"] = 0
+  df = pd.DataFrame(columns=['text', 'keywords'])
+  df["text"] = dataset["text"] 
   print(df)
   for i in tqdm(range(len(df))):
     keyword = kw_model.extract_keywords(df['text'][i])
